@@ -1,14 +1,15 @@
 mod error;
 
 use error::{Error, LogError, Result};
-use miniserde::{json, Deserialize, Serialize};
+use ron::de::from_str;
+use ron::ser::{to_string, to_string_pretty, PrettyConfig};
+use serde::{Deserialize, Serialize};
 use std::cmp::max;
 use std::collections::HashMap;
 use std::fmt;
 use std::fs::remove_file;
 use std::fs::File;
 use std::io::prelude::*;
-use std::num::ParseIntError;
 use std::path::Path;
 use std::process::Command;
 use std::str::FromStr;
@@ -27,18 +28,6 @@ pub struct Keybind {
     pub key: String,
 }
 
-#[derive(Debug)]
-struct NormalHints {
-    min_width: u32,
-    min_height: u32,
-    max_width: u32,
-    max_height: u32,
-    width_inc: u32,
-    height_inc: u32,
-    min_aspect: (u32, u32),
-    max_aspect: (u32, u32),
-}
-
 impl Keybind {
     pub fn new<M, K>(mod_mask: M, key: K) -> Self
     where
@@ -52,25 +41,16 @@ impl Keybind {
     }
 }
 
-impl FromStr for Keybind {
-    type Err = ParseIntError;
-    fn from_str(s: &str) -> Result<Self, Self::Err> {
-        let coords: Vec<&str> = s.split('.').collect();
-
-        let a = coords[0].parse::<u32>()?;
-        let b = coords[1];
-
-        Ok(Keybind {
-            mod_mask: a,
-            key: b.to_string(),
-        })
-    }
-}
-
-impl fmt::Display for Keybind {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}.{}", self.mod_mask, self.key)
-    }
+#[derive(Debug)]
+struct NormalHints {
+    min_width: u32,
+    min_height: u32,
+    max_width: u32,
+    max_height: u32,
+    width_inc: u32,
+    height_inc: u32,
+    min_aspect: (u32, u32),
+    max_aspect: (u32, u32),
 }
 
 #[derive(Clone, Debug, Eq, PartialEq, Serialize, Deserialize, Hash)]
@@ -182,7 +162,7 @@ pub struct SerializableConf {
     pub command_callbacks: HashMap<Events, Vec<String>>,
 }
 
-const UMBERWM_CONF: &str = "umberwm.json";
+const UMBERWM_CONF: &str = "umberwm.ron";
 
 fn umberwm_conf() -> String {
     format!(
@@ -196,7 +176,8 @@ impl SerializableConf {
     pub fn save(&self) -> Result<()> {
         let path = umberwm_conf();
         let mut file = File::create(path.clone())?;
-        let string = json::to_string(&self);
+        let conf = PrettyConfig::new();
+        let string = to_string_pretty(&self, conf)?;
         file.write_all(string.as_bytes())?;
         println!("generated configuration in {}", path);
         Ok(())
@@ -205,7 +186,7 @@ impl SerializableConf {
         let mut file = File::open(umberwm_conf())?;
         let mut contents = String::new();
         file.read_to_string(&mut contents)?;
-        Ok(json::from_str(contents.as_str())?)
+        Ok(from_str(contents.as_str())?)
     }
 
     pub fn exists() -> bool {
@@ -692,12 +673,12 @@ impl UmberWm {
 
     fn serialize_and_quit(&mut self) -> Result<()> {
         let mut file = File::create(UMBERWM_STATE)?;
-        let string = json::to_string(&SerializableState {
+        let string = to_string(&SerializableState {
             float_windows: self.float_windows.clone(),
             overlay_windows: self.overlay_windows.clone(),
             workspaces: self.workspaces.clone(),
             current_workspace: self.current_workspace.clone(),
-        });
+        })?;
         file.write_all(string.as_bytes())?;
         std::process::exit(123);
     }
@@ -1175,7 +1156,7 @@ fn load_serializable_state(conf: &Conf) -> Result<SerializableState> {
         let mut file = File::open(UMBERWM_STATE)?;
         let mut contents = String::new();
         file.read_to_string(&mut contents)?;
-        let res: SerializableState = json::from_str(contents.as_str())
+        let res: SerializableState = from_str(contents.as_str())
             .map_err(|_| Error::FailedToDeserializeFromJson(contents.to_owned()))?;
         remove_file(UMBERWM_STATE)?;
         Ok(res)
@@ -1211,7 +1192,7 @@ pub fn umberwm_from_conf() -> Result<UmberWm> {
     let mut file = File::open(umberwm_conf())?;
     let mut contents = String::new();
     file.read_to_string(&mut contents)?;
-    let res: SerializableConf = json::from_str(contents.as_str())
+    let res: SerializableConf = from_str(contents.as_str())
         .map_err(|_| Error::FailedToDeserializeFromJson(contents.to_owned()))?;
     Ok(umberwm(Conf {
         serializable: res,
